@@ -419,7 +419,7 @@ class BeagleConfig(OmapConfig):
     boot_script = 'boot.scr'
     extra_boot_args_options = (
         'earlyprintk fixrtc nocompcache vram=12M '
-        'omapfb.mode=dvi:1280x720MR-16@60')
+        'omapfb.mode=dvi:1280x720MR-16@60 mpurate=${mpurate}')
 
 
 class OveroConfig(OmapConfig):
